MemoryCacheStorage<T> class final

A simple in-memory cache storage implementation

Implemented types

Constructors

MemoryCacheStorage({int? maxEntries})

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxEntries → int?
Optional maximum entry count, evicting the least recently used entry.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → Future<void>
Clear the cache.
override
delete(String key) → Future<void>
Delete a cache entry by its key.
override
get(String key) → Future<CacheEntry<T>?>
Get a cache entry by its key.
override
keys() → Future<List<String>>
Get all keys in the cache.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String key, CacheEntry<T> value) → Future<void>
Set a cache entry by its key.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited